@@ -31,12 +31,13 @@ class SecretManager:
         if self._client:
             return self._client
 
+        region_name = self.current_env_data["project"]["aws_region"]
         if not os.getenv("AWS_ACCESS_KEY_ID_SHARED", None):
             # just initialize, will check for `.aws/credentials` file
-            self._client = boto3.client("secretsmanager")
+            self._client = boto3.client("secretsmanager", region_name=region_name)
             return self._client
 
-        aws_config = Config(region_name=self.current_env_data["project"]["aws_region"])
+        aws_config = Config(region_name=region_name)
         client_config = {
             "config": aws_config,
             "aws_access_key_id": os.environ["AWS_ACCESS_KEY_ID_SHARED"],
